SystemOrganization addCategory: #'Khami-Test-Core'!
SystemOrganization addCategory: #'Khami-Test-Core-Support'!
SystemOrganization addCategory: #'Khami-Test-Utilities'!
SystemOrganization addCategory: #'Khami-Test-Web'!

TestResource subclass: #KmSuspendAutoTestResource
	instanceVariableNames: 'autotestState'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Utilities'!

!KmSuspendAutoTestResource commentStamp: 'StuartHerring 5/9/2011 21:14' prior: 0!
TestCases that depend on this resource will prevent Autotest from running while they run.
This is useful for tests that perform any compilation activity which might confuse Autotest.!

!KmSuspendAutoTestResource methodsFor: 'running' stamp: 'StuartHerring 5/9/2011 21:23'!
setUp
	autotestState := (Smalltalk at: #AutotestListener 
		ifPresent: [ :c | c allInstances anySatisfy:  [ :l | 
				SystemChangeNotifier uniqueInstance hasNotificationsFor: l]]) 
		ifNil: [false].
	autotestState ifTrue: [ (Smalltalk at: #AutotestDashboard) close ]! !

!KmSuspendAutoTestResource methodsFor: 'running' stamp: 'StuartHerring 5/9/2011 21:26'!
tearDown
	autotestState ifTrue: [ (Smalltalk at: #AutotestDashboard) open ]! !

TestCase subclass: #KmDirectionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:17'!
testOppositeBottom
	self assert: Top equals: Bottom opposite! !

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:17'!
testOppositeLeft
	self assert: Right equals: Left opposite! !

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:17'!
testOppositeRight
	self assert: Left equals: Right opposite! !

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:16'!
testOppositeTop
	self assert: Bottom equals: Top opposite! !

TestCase subclass: #KmGameTest
	instanceVariableNames: 'testGame gameWithNoValidMove gameWithValidMove gameWithMoveAvailableAfterRotation player1 player2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmGameTest methodsFor: 'running' stamp: 'StuartHerring 5/10/2011 21:46'!
setUp
	super setUp.
	player1 := KmPlayer named: 'Player 1' withColour: Color blue.
	player2 := KmPlayer named: 'Player 2' withColour: Color red.
	testGame := KmGame testGame.
	gameWithNoValidMove := KmGame tileSet: (KmTileSet buildFromStrings: {'VFFFV----'. 'FFFFFFFFF'}).
	gameWithValidMove := KmGame tileSet: (KmTileSet buildFromStrings: {'FFFFFFFFF'. 'FFFFVFFFF'. 'FFFFVFFFF'}).
	gameWithMoveAvailableAfterRotation := KmGame tileSet: (KmTileSet buildFromStrings: {'VFFFV----'. 'VFFFVFFFF'}).! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:47'!
testAddingAPlayerIncreasesThePlayerCount
	testGame addPlayer: player1.
	self assert: 1 equals: testGame players size.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:57'!
testCallingValidMoveAvailableDoesntChangeRotation
	| game tileSegment |
	game := gameWithValidMove.
	game takeTile.
	tileSegment := game currentTile at: Top.
	game validMoveAvailable.
	self assert: tileSegment equals: (game currentTile at: Top).! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:26'!
testCantPlaceTileInInvalidLocation
	| game |
	game := gameWithNoValidMove.
	game takeTile.
	self should: [ game placeCurrentTileAtRow: 1 andColumn: 1] raise: KmInvalidMove
! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:50'!
testCurrentPlayerIsSetByNextPlayer
	testGame addPlayer: player1.
	testGame nextPlayer.
	self assert: player1 equals: testGame currentPlayer.  ! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testCurrentTileStartsBlank
	 | game |
	game := testGame.
	self assert: nil equals: game currentTile.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:58'!
testDiscardTile
	| game |
	game := gameWithNoValidMove.
	game takeTile.
	game discardTile.
	self assert: nil equals: game currentTile! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:58'!
testDiscardTileOnlyAllowedWhenNoValidMoveAvailable
	| game |
	game := gameWithValidMove.
	game takeTile.
	self should: [ game discardTile] raise: KmInvalidGameState.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:41'!
testGameIsComplete
	| game |
	game := gameWithValidMove.
	game takeTile.
	game placeCurrentTileAtRow: 2 andColumn: 1.
	game takeTile.
	game placeCurrentTileAtRow: 2 andColumn: 1.
	self assert: game isComplete! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:22'!
testGameIsNotComplete
	self deny: gameWithValidMove isComplete! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:49'!
testGameStartsWithNoPlayers
	self assert: 0 equals: testGame players size.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:47'!
testNextPlayerGetsFirstPlayerFirstTime
	testGame addPlayer: player1.
	self assert: player1 equals: testGame nextPlayer.  ! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:49'!
testNextPlayerGetsSecondPlayerSecondTime
	testGame addPlayer: player1.  
	testGame addPlayer: player2.
	testGame nextPlayer.
	self assert: player2 equals: testGame nextPlayer.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:53'!
testNextPlayerLoopsAfterLastPlayer
	testGame addPlayer: player1.  
	testGame addPlayer: player2.
	testGame nextPlayer.
	testGame nextPlayer.
	self assert: player1 equals: testGame nextPlayer.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:58'!
testNoValidMoveAvailable
	| game |
	game := gameWithNoValidMove.
	game takeTile.
	self deny: game validMoveAvailable.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:35'!
testPlaceTile
	| game gameBoard tile | 
	game := gameWithValidMove.
	gameBoard := game board.
	tile := game takeTile.
	game placeCurrentTileAtRow: 1 andColumn: 2.
	self assert: tile equals: (gameBoard at: 2 at: 2)! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:36'!
testPlaceTileClearsCurrentTile
	| game |
	game := gameWithValidMove.
	game takeTile.
	game placeCurrentTileAtRow: 1 andColumn: 2.
	self assert: nil equals: testGame currentTile! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:27'!
testPlaceTileSetsLastTile
	| game gameBoard tile | 
	game := gameWithValidMove.
	gameBoard := game board.
	tile := game takeTile.
	game placeCurrentTileAtRow: 1 andColumn: 2.
	self assert: tile equals: game lastTile! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:38'!
testPlaceTileWontReplaceExistingTile
	| game gameBoard | 
	game := gameWithValidMove.
	gameBoard := game board.
	game takeTile.
	game placeCurrentTileAtRow: 1 andColumn: 2.
	game takeTile.
	self should: [game placeCurrentTileAtRow: 2 andColumn: 2] raise: KmInvalidMove.
! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testTakeTileSetsCurrentTile
	| game tile |
	game := testGame.
	tile := game takeTile.
	self assert: tile equals: game currentTile.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testTakeTileTwiceDoesntTakeAdditionalTile
	| game tile |
	game := testGame.
	tile := game takeTile.
	self assert: tile equals: game takeTile! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:58'!
testValidMoveAvailable
	| game |
	game := gameWithValidMove.
	game takeTile.
	self assert: game validMoveAvailable.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:58'!
testValidMoveAvailableAfterRotation
	| game |
	game := gameWithMoveAvailableAfterRotation.
	game takeTile.
	self assert: game validMoveAvailable.! !

TestCase subclass: #KmPieceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmPieceTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 22:22'!
testPieceColourIsPlayerColour
	self assert: Color blue 
		equals: (KmPiece forPlayer: (KmPlayer named: 'Player 1' withColour: Color blue)) colour! !

!KmPieceTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:24'!
testPiecePlayer
	| p |
	p := KmPlayer new.
	self assert: p equals: (KmPiece forPlayer: p) player! !

TestCase subclass: #KmPlayerTest
	instanceVariableNames: 'player'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmPlayerTest methodsFor: 'fixtures' stamp: 'StuartHerring 5/9/2011 20:14'!
playerColour
	^Color blue! !

!KmPlayerTest methodsFor: 'fixtures' stamp: 'StuartHerring 5/9/2011 20:14'!
playerName
	^'Player 1'! !

!KmPlayerTest methodsFor: 'running' stamp: 'StuartHerring 5/9/2011 20:14'!
setUp
	player := KmPlayer named: self playerName withColour: self playerColour.! !

!KmPlayerTest methodsFor: 'fixtures' stamp: 'StuartHerring 5/9/2011 20:14'!
startingPieces
	^5! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:11'!
testCantReturnPieceBelongingToAnotherPlayer
	| player2 |
	player2 := KmPlayer named: 'Player 2' withColour: Color red.
	self should: [ player returnPiece: player2 takePiece ] raise: Error
! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:18'!
testPieceTakenFromPlayerBelongsToPlayer
	self assert: player equals: player takePiece player! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:17'!
testPlayerColour
	self assert: self playerColour equals: player colour! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:14'!
testPlayerName
	self assert: self playerName equals: player name! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:15'!
testPlayerStartingPieceCount
	self assert: self startingPieces equals: player pieces size.! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:27'!
testReturnPieceIncreasesCount
	| p |
	p := player takePiece.
	player returnPiece: p.
	self assert: self startingPieces equals: player pieces size.! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 07:38'!
testStartingScore
	self assert: 0 equals: player score.! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:17'!
testTakePieceDeductsItFromPlayersPieces
	player takePiece.
	self assert: (self startingPieces - 1) equals: player pieces size.! !

TestCase subclass: #KmSessionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Web'!

!KmSessionTest methodsFor: 'tests' stamp: 'StuartHerring 4/10/2011 22:13'!
testCurrentTileStartsAsNil
	| session |
	session := KmSession new.
	session game: KmGame testGame.
	self assert: session currentTile equals: nil! !

TestCase subclass: #KmTerritoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 4/22/2011 14:00'!
testCompleteVillage
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'VFFFVFFFF'.
	tile2 := KmTile buildFromString: 'FFVFFFVFF'.
	tile1 tileAt: Top put: tile2.
	self assert: (tile1 at: Top) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:13'!
testInitialTerritoryDoesNotHaveAPiece
	self deny: KmTerritory new hasPieces! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:13'!
testInitialTerritoryHasZeroPieces
	self assert: 0 equals: KmTerritory new pieces size.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testIsComplete
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'FFFF-FFFF'.
	tile2 := KmTile buildFromString: 'FFFFFF-FF'.
	tile1 tileAt: Top put: tile2.
	self assert: (tile1 at: Top) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:46'!
testLoopContentsIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: LeftBottom) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:47'!
testLoopContentsSegmentIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: LeftBottom) isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:48'!
testLoopIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: Left) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:49'!
testLoopSegmentIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: Left) isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testMergeWith
	| s1 s2 |
	s1 := KmFarmRegion new.
	s2 := KmFarmRegion new.
	s1 territory mergeWith: s2 territory.
	self assert: s2 territory equals: s1 territory! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testMergeWithAddsSegments
	| s1 s2 |
	s1 := KmFarmRegion new.
	s2 := KmFarmRegion new.
	s1 territory mergeWith: s2 territory.
	self assert: 2 equals: s1 territory size! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testMergeWithRemovesAllSegments
	| s1 s2 territory |
	s1 := KmFarmRegion new.
	territory := s1 territory.
	s2 := KmFarmRegion new.
	s1 territory mergeWith: s2 territory.
	self assert: territory isEmpty! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:29'!
testMergingTerritoriesWithPiecesGivesSumOfPieces
	| s t |
	s := KmTileSegment fromChar: $F in: nil.
	s piece: KmPiece new.
	t := s territory.

	s := KmTileSegment fromChar: $F in: nil.
	s piece: KmPiece new.
	s territory mergeWith: t.  
	self assert: 2 equals: t pieces size.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testNotComplete
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'FFFF-FFFF'.
	tile2 := KmTile buildFromString: 'FFFF-F-F-'.
	tile1 tileAt: Top put: tile2.
	self deny: (tile1 at: Top) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:12'!
testTerritoryWithSegmentContainingPieceHasExactlyOnePiece
	| s t |
	s := KmTileSegment fromChar: $F in: nil.
	t := s territory.
	s piece: KmPiece new.
	self assert: 1 equals: t pieces size.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:13'!
testTerritoryWithSegmentContainingPieceHasPieces
	| s t |
	s := KmTileSegment fromChar: $F in: nil.
	t := s territory.
	s piece: KmPiece new.
	self assert: t hasPieces! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testTilesInSingleTile
	| tile |
	tile := KmTile blank.
	self assert: 1 equals: tile territories any tiles size.! !

TestCase subclass: #KmTestGameBoard
	instanceVariableNames: 'gameBoard'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTestGameBoard methodsFor: 'running' stamp: 'StuartHerring 3/7/2011 21:19'!
setUp
	super setUp.
	gameBoard := KmGameBoard startingTile: KmTile startingTile.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCanPlaceTile
	self assert: (gameBoard canPlaceTile: KmTile blank at: 3 at: 2) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCantPlaceTileBecauseAlreadyOccupied
	self deny: (gameBoard canPlaceTile: KmTile blank at: 2 at: 2) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCantPlaceTileBecauseDoesntConnect
	self deny: (gameBoard canPlaceTile: KmTile blank at: 1 at: 2) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCantPlaceTileBecauseNotAvailable
	self deny: (gameBoard canPlaceTile: KmTile blank at: 1 at: 1) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:18'!
testInitialColumnsIs3
	self assert: 3 equals: gameBoard columns.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:18'!
testInitialRowsIs3
	self assert: 3 equals: gameBoard rows.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:19'!
testPlaceTile
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 2 put: tile.
	self assert: tile equals: (gameBoard at: 3 at: 2)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:19'!
testPlaceTileAtBottomEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 2 put: tile.
	self assert: 4 equals: gameBoard rows.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testPlaceTileAtLeftEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 2 at: 1 put: tile.
	self assert: 4 equals: gameBoard columns.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtLeftEdgeExtendsBoardAndRelocates
	 | tile |
	tile := KmTile blank.
	gameBoard at: 2 at: 1 put: tile.
	self assert: tile equals: (gameBoard at: 2 at: 2)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtRightEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 1 put: tile.
	self assert: 4 equals: gameBoard columns.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtTopEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 1 at: 2 put: tile.
	self assert: 4 equals: gameBoard rows.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtTopEdgeExtendsBoardAndRelocates
	 | tile |
	tile := KmTile blank.
	gameBoard at: 1 at: 2 put: tile.
	self assert: tile equals: (gameBoard at: 2 at: 2)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileConnectsItToItsNeighbour
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 2 put: tile.
	self assert: tile equals: ((gameBoard at: 2 at: 2) tileAt: Bottom)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:18'!
testStartingTileAtCentre
	| board |
	board := gameBoard.
	self assert: board startingTile equals: (board at: 2 at: 2)! !

TestCase subclass: #KmTestGrid
	instanceVariableNames: 'fiveBySeven'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core-Support'!

!KmTestGrid methodsFor: 'running' stamp: 'StuartHerring 1/29/2011 12:42'!
setUp
	fiveBySeven := KmGrid ofSize: 5 by: 7.
	1 to: 5 do: [ :row |
		1 to: 7 do: [ : column | fiveBySeven at: row at: column put: row displayString, 'x', column displayString]] ! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:22'!
testAddColumn
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid addColumn.
	self assert: 8 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testAddColumns
	| grid |
	grid := KmGrid new.
	grid addColumns: 7.
	self assert: 7 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:21'!
testAddRow
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid addRow.
	self assert: 6 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testAddRows
	| grid |
	grid := KmGrid new.
	grid addRows: 5.
	self assert: 5 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 19:57'!
testAdjacentItems
	self assert: ({'1x2'. '2x3'. '3x2'. '2x1' } hasEqualElements: (fiveBySeven adjacentItemsAt: 2 at: 2))! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testEmptyGridColumns
	self assert: 0 equals: KmGrid new columns ! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testEmptyGridRows
	self assert: 0 equals: KmGrid new rows! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testInitialDataIsNil
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	self assert: nil equals: (grid at: 3 at: 4)! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testInitialSizeColumns
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	self assert: 7 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testInitialSizeRows
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	self assert: 5 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:17'!
testPrependColumn
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid prependColumn.
	self assert: 8 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:14'!
testPrependColumnMovesItems
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid at: 2 at: 2 put: 'foo'.
	grid prependColumn.
	self assert: nil equals: (grid at: 2 at: 2).
	self assert: 'foo' equals: (grid at: 2 at: 3).! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:16'!
testPrependRow
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid prependRow.
	self assert: 6 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:16'!
testPrependRowMovesItems
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid at: 2 at: 2 put: 'foo'.
	grid prependRow.
	self assert: nil equals: (grid at: 2 at: 2).
	self assert: 'foo' equals: (grid at: 3 at: 2).! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testPutAndRetrieve
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid at: 3 at: 4 put: 'foo'.
	self assert: 'foo' equals: (grid at: 3 at: 4)! !

TestCase subclass: #KmTileSegmentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testBlockerIsIncomplete
	self deny: KmBlocker new isComplete! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testBlockerSegmentCannotHavePiece
	self deny: KmBlocker new canPlacePiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testBlockerSegmentIsNotAnything
	| segment |
	segment := KmBlocker new.
	self deny: segment isVillage.
	self deny: segment isHut.
	self deny: segment isFarm.
	self deny: segment isRoad! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testBlockerTypeIsBlocker
	self assert: #blocker equals: KmBlocker new type! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testCompletingTerritoryCompletesSegment
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'FFFF-FFFF'.
	tile2 := KmTile buildFromString: 'FFFFFF-FF'.
	tile1 tileAt: Top put: tile2.
	self assert: (tile1 at: Top) isComplete.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testFarmRegionFromCode
	self assert: KmFarmRegion new isFarm! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:57'!
testFarmSegmentIsFarm
	self assert: KmFarmRegion new isFarm! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testFarmSegmentTypeIsFarm
	self assert: #farm equals: KmFarmRegion new type! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testHutSegmentCanHavePiece
	self assert: KmHut new canPlacePiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:57'!
testHutSegmentIsHut
	self assert: KmHut new isHut! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testHutTypeIsHut
	self assert: #hut equals: KmHut new type! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testInitialSegmentCanHavePiece
	self assert: KmFarmRegion new canPlacePiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testInitialSegmentHasNilPiece
	self assert: KmFarmRegion new piece isNil! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testInitialSegmentHasNoPiece
	self deny: KmFarmRegion new hasPiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testInitialSegmentIsIncomplete
	self deny: KmRoadPath new isComplete! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testNewSegmentIsIncomplete
	self deny: KmFarmRegion new isComplete! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testPieceCanNotBePlacedIfSegmentsTerritoryAlreadyHasAPiece
	| s1 s2 |
	s1 := KmFarmRegion new.
	s2 := KmFarmRegion new.
	s1 territory mergeWith: s2 territory.
	s1 piece: KmPiece new.
	self deny: s2 canPlacePiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testPieceIsReturnedProperly
	| s p |
	s := KmFarmRegion new.
	p := KmPiece new.
	s piece: p.
	self assert: p equals: s piece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testPlacingPieceWhenTerritoryAlreadyContainsAPieceThrowsError
	| s1 s2 |
	s1 := KmFarmRegion new.
	s2 := KmFarmRegion new.
	s1 territory mergeWith: s2 territory.
	s1 piece: KmPiece new.
	self should: [ s2 piece: KmPiece new ] raise: Error! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testRoadConnectsToRoad
	self assert: (KmRoadPath new connectsTo: KmRoadPath new)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testRoadDoesntConnectToBlocker
	self deny: (KmRoadPath new connectsTo: KmBlocker new)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 16:19'!
testRoadPathFromCode
	self assert: (KmTileSegment fromChar: $- in: nil) isRoad! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:57'!
testRoadSegmentIsRoad
	self assert: KmRoadPath new isRoad! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testRoadSegmentTypeIsRoad
	self assert: #road equals: KmRoadPath new type! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testSegmentLocationAfterRotation
	| tile segment |
	tile := KmTile buildFromString: 'VFFFFFFFF'.
	segment := tile at: Top.
	tile rotate.
	self assert: Right equals: segment location.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testSetPieceMeansSegmentHasPiece
	| s |
	s := KmFarmRegion new.
	s piece: KmPiece new.
	self assert: s hasPiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 16:19'!
testUnknownCodeThrowsError
	self should: [ KmTileSegment fromChar: $z in: nil ] raise: Error! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testVillageConnectsToVillage
	self assert: (KmVillageRegion new connectsTo: KmVillageRegion new)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testVillageConnectsToWall
	self assert: (KmVillageRegion new connectsTo: KmVillageWall new)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testVillageDoesntConnectToFarm
	self deny: (KmVillageRegion new connectsTo: KmFarmRegion new)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 16:19'!
testVillageRegionFromCode
	self assert: (KmTileSegment fromChar: $V in: nil) isVillage! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:57'!
testVillageSegmentIsVillage
	self assert: KmVillageRegion new isVillage! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testVillageSegmentTypeIsVillage
	self assert: #village equals: KmVillageRegion new type! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testWallConnectsToVillage
	self assert: (KmVillageWall new connectsTo: KmVillageRegion new)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testWallDoesntConnectToFarm
	self deny: (KmVillageWall new connectsTo: KmFarmRegion new)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testWallDoesntConnectToWall
	self deny: (KmVillageWall new connectsTo: KmVillageWall new)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:58'!
testWallSegmentIsVillage
	self assert: KmVillageWall new isVillage! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:55'!
testWallSegmentTypeIsVillage
	self assert: #village equals: KmVillageWall new type! !

TestCase subclass: #KmTileSetCreation
	instanceVariableNames: 'setName className'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileSetCreation class methodsFor: 'accessing' stamp: 'StuartHerring 5/9/2011 21:13'!
resources
	^{KmSuspendAutoTestResource}! !

!KmTileSetCreation methodsFor: 'running' stamp: 'StuartHerring 3/21/2011 22:17'!
setUp
	super setUp.
	className := #KmTSxxxTestxxx.
	setName := 'xxx Test xxx'.
	Smalltalk at: className ifPresent: [ :c | c removeFromSystem ].
! !

!KmTileSetCreation methodsFor: 'running' stamp: 'StuartHerring 3/21/2011 23:09'!
tearDown
	Smalltalk at: className ifPresent: [ :c | c removeFromSystem ].
! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 21:09'!
testRegisterTileSetCreatesClass	
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: (Smalltalk globals includesKey: className)! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 21:10'!
testRegisterTileSetCreatesClassIsTileSet
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: KmTileSet equals: (Smalltalk at: className) superclass ! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 22:04'!
testRegisteredTileSetCanCreateTileSet
	| tileSet |
	KmTileSet register: setName asTileSetUsingStrings: #('FFFFFFFFF').
	tileSet := (Smalltalk at: className) new.
	self assert: 1 equals: tileSet size.! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 22:54'!
testRegisteredTileSetHasCorrectName
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: setName equals: (Smalltalk at: className) tilesetName! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 22:54'!
testRegisteredTileSetInstanceHasCorrectName
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: setName equals: (Smalltalk at: className) new name! !

TestCase subclass: #KmTileSetTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 23:05'!
testBuildFromStrings
	| set |
	set := KmTileSet buildFromStrings: #('FFFFFFFFF' 'FFFFFFFFF' 'FFFFFFFFF').
	self assert: 3 equals: set size.! !

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 23:05'!
testStartingTileIsFirstInSet
	| set tile1 tile2 |
	tile1 := KmTile blank.
	tile2 := KmTile blank.
	set := KmTileSet buildFromTiles: { tile1. tile2 }.
	self assert: tile1 equals: set takeTile! !

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:36'!
testTakeTileReducesSize
	| set size |
	set := KmTileSet testSet.
	size := set size.
	set takeTile.
	self assert: size - 1 equals: set size.! !

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:44'!
testTakeTileRemovesItFromRemaining
	| set tile |
	set := KmTileSet testSet.
	tile := set takeTile.
	self deny: ((set instVarNamed: #tiles) includes: tile)! !

TestCase subclass: #KmTileTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileTest methodsFor: 'convenience' stamp: 'StuartHerring 1/28/2011 20:33'!
assertMappings: aCollection for: aTile
	self assert: (aCollection allSatisfy: [ :assoc | self verify: assoc key isNumber: assoc value inTile: aTile ]).! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 18:21'!
testAdjacentVillagesInDifferentTerritories
	| tile |
	tile := KmTile buildFromString: 'WWFFVVFFFFFFF'.
	self deny: (tile at: Top) territory = (tile at: Right) territory.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTile
	| tile1 |
	tile1 := KmTile startingTile.
	self assert: (tile1 allowsTile: KmTile blank at: Bottom)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTileReturnsFalse
	| tile1 |
	tile1 := KmTile startingTile.
	self deny: (tile1 allowsTile: KmTile blank at: Top)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTileReturnsFalseDueToPaths
	| tile1 |
	tile1 := KmTile startingTile.
	self deny: (tile1 allowsTile: KmTile blank at: Right)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTileReturnsFalseWhenAlreadyOccupied
	| tile1 |
	tile1 := KmTile startingTile.
	tile1 tileAt: Bottom put: KmTile blank.
	self deny: (tile1 allowsTile: KmTile blank at: Bottom)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testBuildFromString
	| tile |
	tile := KmTile buildFromString: 'VFVFF-F--'.
	self assert: (tile at: TopLeft) isVillage.
	self assert: (tile at: TopRight) isVillage.
	self assert: (tile at: RightTop) isFarm.
	self assert: (tile at: RightBottom) isFarm.
	self assert: (tile at: BottomRight) isVillage.
	self assert: (tile at: BottomLeft) isVillage.
	self assert: (tile at: LeftBottom) isFarm.
	self assert: (tile at: LeftTop) isFarm.

	self assert: (tile at: Top) isFarm. 
	self assert: (tile at: Left) isRoad.
	self assert: (tile at: Bottom) isFarm.
	self assert: (tile at: Right) isRoad.
	self assert: (tile at: Centre) isRoad.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:22'!
testBuildFromStringStopsAtPipe
	KmTile buildFromString: 'FFFFFFFFF|'.
	"Doesn't raise an error"
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:58'!
testCrossroadTerritories
	| tile1 |
	tile1 := KmTile buildFromString: 'FFFF----.'.
	self assert: 9 equals: tile1 territories size.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 5/7/2011 21:02'!
testFarmWithAdjacentVillagesNotComplete
	| tile |
	tile := KmTile buildFromString: 'WWFFVVFFFFFFF'.
	self deny: (tile at: Bottom) territory isComplete ! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:45'!
testInitialPaths
	| tile |
	tile := KmTile blank.
	self assertMappings: {
		Top -> 2.
		CentreTop -> 3.
		Right -> 6.
		CentreRight -> 7.
		Bottom -> 10.
		CentreBottom -> 11.
		Left -> 14.
		CentreLeft -> 15.
		Centre ->0 } for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:48'!
testInitialRegions
	| tile |
	tile := KmTile blank.
	self assertMappings: {
		TopLeft -> 1. TopRight -> 4.
		RightTop -> 5. RightBottom -> 8.
		BottomRight -> 9. BottomLeft ->12.
		LeftBottom -> 13. LeftTop -> 16} for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testNewTileHasNothingAdjacent
	 | tile |
	tile := KmTile blank.
	self assert: nil equals: (tile tileAt: Top).
	self assert: nil equals: (tile tileAt: Right).
	self assert: nil equals: (tile tileAt: Bottom).
	self assert: nil equals: (tile tileAt: Left)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 18:23'!
testNinePartStringSetsCentreLikeEdge
	| tile |
	tile := KmTile buildFromString: 'FFFF-FFFF'.
	self assert: (tile at: CentreTop) isRoad.
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testPlaceTile
	 | t1 t2 |
	t1 := KmTile blank.
	t2 := KmTile blank.
	
	t1 tileAt: Top put: t2.
	self assert: t2 equals: (t1 tileAt: Top)
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testPlaceTileSetsReciprocalTile
	 | t1 t2 |
	t1 := KmTile blank.
	t2 := KmTile blank.
	
	t1 tileAt: Top put: t2.
	self assert: t1 equals: (t2 tileAt: Bottom)
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 13:07'!
testPlacingTileMergesTerritories
	| tile1 tile2 |
	tile1 := KmTile blank.
	tile2 := KmTile blank.
	tile1 tileAt: Left put: tile2.
	self assert: tile1 territories equals: tile2 territories! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:49'!
testRotatedPaths
	| tile |
	tile := KmTile blank.
	tile rotate.
	self assertMappings: {
		Top -> 14.
		CentreTop -> 15.
		Right -> 2.
		CentreRight -> 3.
		Bottom -> 6.
		CentreBottom -> 7.
		Left -> 10.
		CentreLeft -> 11.
		Centre ->0 } for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:59'!
testRotatedRegions
	| tile |
	tile := KmTile blank.
	tile rotate.
	self assertMappings: {
		TopLeft -> 13. TopRight -> 16.
		RightTop -> 1. RightBottom -> 4.
		BottomRight -> 5. BottomLeft ->8.
		LeftBottom -> 9. LeftTop -> 12} for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:23'!
testSimpleTerritories
	| tile1 |
	tile1 := KmTile blank.
	self assert: 1 equals: tile1 territories size.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 18:23'!
testThirteenPartStringSetsCentreSeparately
	| tile |
	tile := KmTile buildFromString: 'FFFF-FFFFFFFF'.
	self assert: (tile at: CentreTop) isFarm.
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 20:01'!
testWallsOnDifferentTilesStillConnect
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'WFFFVFFFF'.
	tile2 := KmTile buildFromString: 'FFWFFFVFF'.
	self assert: (tile1 allowsTile: tile2 at: Top)! !

!KmTileTest methodsFor: 'convenience' stamp: 'StuartHerring 1/28/2011 20:34'!
verify: aSymbol isNumber: aNumber inTile: aTile
	^((aTile instVarNamed: #regions) at: aNumber) = (aTile at: aSymbol)! !

TestRunner subclass: #KmTestRunner
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Utilities'!

!KmTestRunner methodsFor: 'utilities' stamp: 'StuartHerring 2/13/2011 22:30'!
findCategories
	^Smalltalk organization categories select: [ :c | c beginsWith: 'Khami-Test'].! !

!KmTestRunner methodsFor: 'utilities' stamp: 'StuartHerring 2/13/2011 22:30'!
findClassesForCategories: aCollection
	| items |
	aCollection isEmpty
		ifTrue: [ ^ self findClassesForCategories: self findCategories ].
	items := aCollection
		gather: [ :category | 
			((Smalltalk organization listAtCategoryNamed: category) collect: [ :each | Smalltalk globals at: each ])
				select: [ :each | each includesBehavior: self baseClass ] ].
	^ items asSet! !
